#######################
Single spectrum fitting
#######################

Whilst ``mcfine`` has primarily been built to fit cubes, you can also use
it to fit single spectra. Here, we have some tutorials to generate and fit
a spectrum, and then explore that fitted spectrum.

.. toctree::
   :maxdepth: 2
   :caption: Single Spectra Fitting

   generating_a_spectrum
   fitting_a_spectrum
   plotting_a_spectrum